@@ -64,41 +64,40 @@ const common = () => {
     nav.init();
     fontawesome();
 
-
-    function formUpdate(){
-        var checker = false;
-        var checkCount = 0;
-        checker = setInterval(function(){
+    function formUpdate() {
+        let checker = false;
+        let checkCount = 0;
+        checker = setInterval(function() {
             checkCount++;
-            if($('.timeslot-lists.ts-grid-container li').length > 0 || checkCount > 15){
+            if ($('.timeslot-lists.ts-grid-container li').length > 0 || checkCount > 15) {
                 clearInterval(checker);
                 checkCount = 0;
-
-
-        // Select the target node.
-                var target = $(document).find('#show_time_slot')[0];
+                // Select the target node.
+                const target = $(document).find('#show_time_slot')[0];
                 // Create an observer instance.
-                var observer = new MutationObserver(function(mutations) {
-                    $('.timeslot-lists.ts-grid-container li').each(function(i,j){
-                    
-                        var currTxt = $(j).find('a').text();
-                        
-                        if(currTxt == '09:00 - 13:00'){
+                const observer = new MutationObserver(function(mutations) {
+                    $('.timeslot-lists.ts-grid-container li').each(function(i,j) {
+                        const currTxt = $(j).find('a')
+                            .text();
+                        if (currTxt === '09:00 - 13:00') {
                             //half day morning
-                            $(j).find('a').html('<input type="radio" name="time_slots" value="' + currTxt + '" class="time_slot">Half day (' + currTxt + ')');
+                            $(j).find('a')
+                                .html(`<input type="radio" name="time_slots" value="${currTxt}" class="time_slot">Half day (${currTxt})`);
                             $(j).appendTo('.timeslot-lists.ts-grid-container');
                         }
-                        if(currTxt == '13:00 - 17:00'){
+                        if (currTxt === '13:00 - 17:00') {
                             //half day afternoon
-                            $(j).find('a').html('<input type="radio" name="time_slots" value="' + currTxt + '" class="time_slot">Half day (' + currTxt + ')');
+                            $(j).find('a')
+                                .html(`<input type="radio" name="time_slots" value="${currTxt}" class="time_slot">Half day (${currTxt})`);
                             $(j).appendTo('.timeslot-lists.ts-grid-container');
                         }
-                        if(currTxt == '09:00 - 17:00'){
+                        if (currTxt === '09:00 - 17:00') {
                             //full day
-                            $(j).find('a').html('<input type="radio" name="time_slots" value="' + currTxt + '" class="time_slot">Full day (' + currTxt + ')');
+                            $(j).find('a')
+                                .html(`<input type="radio" name="time_slots" value="${currTxt}" class="time_slot">Full day (${currTxt})`);
                             $(j).appendTo('.timeslot-lists.ts-grid-container');
                         }
-                    });   
+                    });
                 });
 
                 // Pass in the target node, as well as the observer options.
@@ -108,28 +107,28 @@ const common = () => {
                     characterData: true
                 });
 
-                $('.timeslot-lists.ts-grid-container li').each(function(i,j){
-                    
-                    var currTxt = $(j).find('a').text();
-                    
-                    if(currTxt == '09:00 - 13:00'){
+                $('.timeslot-lists.ts-grid-container li').each(function(i,j) {
+                    const currTxt = $(j).find('a')
+                        .text();
+                    if (currTxt === '09:00 - 13:00') {
                         //half day morning
-                        $(j).find('a').html('<input type="radio" name="time_slots" value="' + currTxt + '" class="time_slot">Half day (' + currTxt + ')');
+                        $(j).find('a')
+                            .html(`<input type="radio" name="time_slots" value="${currTxt}" class="time_slot">Half day (${currTxt})`);
                         $(j).appendTo('.timeslot-lists.ts-grid-container');
                     }
-                    if(currTxt == '13:00 - 17:00'){
+                    if (currTxt === '13:00 - 17:00') {
                         //half day afternoon
-                        $(j).find('a').html('<input type="radio" name="time_slots" value="' + currTxt + '" class="time_slot">Half day (' + currTxt + ')');
+                        $(j).find('a')
+                            .html(`<input type="radio" name="time_slots" value="${currTxt}" class="time_slot">Half day (${currTxt})`);
                         $(j).appendTo('.timeslot-lists.ts-grid-container');
                     }
-                    if(currTxt == '09:00 - 17:00'){
+                    if (currTxt === '09:00 - 17:00') {
                         //full day
-                        $(j).find('a').html('<input type="radio" name="time_slots" value="' + currTxt + '" class="time_slot">Full day (' + currTxt + ')');
+                        $(j).find('a')
+                            .html(`<input type="radio" name="time_slots" value="${currTxt}" class="time_slot">Full day (${currTxt})`);
                         $(j).appendTo('.timeslot-lists.ts-grid-container');
                     }
-                });  
-
-                
+                });
             }
         }, 200);
     }
@@ -138,16 +137,13 @@ const common = () => {
         $('#hero-video')[0].play();
         $('#hero-video').attr('data-status','play');
     }
-    
-    
-    if($('#bkap-booking-form').length > 0){
+
+
+    if ($('#bkap-booking-form').length > 0) {
         formUpdate();
-
-
-        $(document).on('click', '#inline_calendar', function(){
+        $(document).on('click', '#inline_calendar', function() {
             formUpdate();
         });
-        
     }
 
     $('#video-toggle').click(function() {
